@@ -3,6 +3,7 @@ import snappi
 from trex.stl.api import *
 from snappi_trex.validation import Validation
 from snappi_trex.setconfig import SetConfig
+from snappi_trex.capture import Capture
 
 
 class Api(snappi.Api):
@@ -31,8 +32,9 @@ class Api(snappi.Api):
         )
         self._c = STLClient()
         self._port_ids = []
-        self._captures = []
         self._transmit_state = 'stop'
+        self._capture = Capture(self._c)
+
         try:
             # connect to server
             self._c.connect()
@@ -150,19 +152,8 @@ class Api(snappi.Api):
     def set_capture_state(self, payload):
         """Starts capture on all ports that have capture enabled.
         """
-        cs = json.loads(payload.serialize())
-        ports = list(range(len(self._port_ids)))
-        if cs['port_names'] is not None:
-            ports = []
-            for f_name in cs['port_names']:
-                ports.append(self._port_ids.index(f_name))
         try:
-            if cs['state'] == 'start':
-                self._captures.append(self._c.start_capture(rx_ports = ports))
-            elif cs['state'] == 'stop':
-                while len(self._captures) > 0:
-                    cap = self._captures.pop(0)
-                    self._c.stop_capture(cap['id'], "/home/frederick/cap/cap_{}.pcap".format(cap['id']))
+            self._capture.set_capture(payload, self._port_ids)
         except STLError as e:
             self._c.disconnect()
             print(e)
@@ -171,6 +162,7 @@ class Api(snappi.Api):
     def get_capture(self, request):
         """Gets capture file and returns it as a byte stream
         """
+        return self._capture.get_capture(request)
         
 
     def get_metrics(self, request):
