@@ -8,7 +8,7 @@ class ValueOptions:
     This class also contains useful utility functions for configuration
     """
 
-    def get_value_cmds(layer_type, layer_cnt, header_field, length, field_str, fixup=0, bit_fixup=0):
+    def get_value_cmds(layer_type, layer_cnt, header_field, length, field_str, bit_fixup=0):
         """
         Returns the set of VM instructions to configure a specific header field
         to a value option. 
@@ -25,6 +25,8 @@ class ValueOptions:
             - bit_fixup: An int representing how many packet bits to go forward when writing the field bits.
                 (Use this when the header field starts in the middle of a byte)
         """
+        fixup = bit_fixup // 8
+        bit_fixup %= 8
         varname = "{0}{1}_{2}:{3}".format(layer_type, layer_cnt-1, field_str, 8*fixup + bit_fixup)
         vm_cmds = []
         mask = Util.get_mask(length)
@@ -76,9 +78,6 @@ class ValueOptions:
             vm_cmds.append(STLVmFlowVar(name=varname, size=numBytes, init_value = init,
                 min_value=minV, max_value=maxV, step=step, op='dec'
             ))
-
-        else: 
-            raise STLError('Invalid {0} operation'.format(varname))
         
         # Write the first n bits of the variable to the first n bits of the packet field
         pkt_offset = "{0}:{1}.{2}".format(layer_type, layer_cnt-1, field_str)
@@ -140,9 +139,6 @@ class ValueOptions:
             vm_cmds.append(STLVmFlowVar(name=varname, size=8, init_value = init,
                 min_value=minV, max_value=maxV, step=step, op='dec'
             ))
-
-        else: 
-            raise STLError('Invalid {0} operation'.format(varname))
         
         pkt_offset = "{0}:{1}.{2}".format(layer_type, layer_cnt-1, field_str)
         bit_shift = 64-length
